@@ -152,10 +152,16 @@ class Pipeline(object):
             fmax=conf['data']['fmax'],
             nchans=conf['data']['nchans'],
         )
-        self.worker_pool = WorkerPool(conf['dereddening'], conf['ranges'], processes=conf['processes'])
-
         log.debug("Input files: {}".format(len(files)))
         self.dmiter.prepare(files, fmt=self.config['data']['format'])
+
+        # NOTE: call dmiter.prepare() first. Before that, dmiter.tsloader is None
+        self.worker_pool = WorkerPool(
+            conf['dereddening'], 
+            conf['ranges'],
+            loader=self.dmiter.tsloader,
+            processes=conf['processes']
+        )
         log.info("Pipeline ready")
         
     @timing
@@ -165,9 +171,9 @@ class Pipeline(object):
         """
         log.info("Running search")
         peaks = []
-        for chunk in self.dmiter.iterate(chunksize=self.config['processes']):
+        for fnames in self.dmiter.iterate_fnames(chunksize=self.config['processes']):
             peaks.extend(
-                self.worker_pool.process_chunk(chunk)
+                self.worker_pool.process_fname_list(fnames)
             )        
         self.peaks = sorted(peaks, key=lambda p: p.period)
         log.info("Total peaks found: {}".format(len(peaks)))
@@ -419,6 +425,13 @@ def get_parser():
         default=os.getcwd(),
         help="Output directory for the data products",
     )
+    parser.add_argument(
+        "-f", 
+        "--logfile",
+        type=str,
+        default=None,
+        help="Save logs to given file. If not specified, no logfile is saved"
+    )
     parser.add_argument(
         "--log-level",
         type=str,
@@ -454,13 +467,16 @@ def run_program(args):
     import matplotlib.pyplot as plt
     plt.switch_backend('Agg')
 
-    logging.basicConfig(
-        level=logging.DEBUG,
-        format="%(asctime)s %(filename)18s:%(lineno)-4s %(levelname)-8s %(message)s"
-        )
+    handlers = [logging.StreamHandler()]
+    if args.logfile:
+        handlers.append(logging.FileHandler(args.logfile, mode='w'))
 
-    logging.getLogger('matplotlib').setLevel('WARNING') # otherwise it gets annoying
-    logging.getLogger('riptide').setLevel(args.log_level)
+    logging.basicConfig(
+        level=args.log_level,
+        format='%(asctime)s %(filename)18s:%(lineno)-4s %(levelname)-8s %(message)s',
+        handlers=handlers
+    )
+    logging.getLogger('matplotlib').setLevel('WARNING') # otherwise it can get annoying
 
     if args.log_timings:
         logging.getLogger('riptide.timing').setLevel('DEBUG')
